@@ -1,6 +1,6 @@
-from .ext import Admin
-from .decorators import admin_required
-from .api.decorators import admin_required_api
 from . import cli
+from .api.decorators import admin_required_api
+from .ext import Admin
+from .ui.decorators import admin_required
 
 __all__ = ["Admin", "admin_required", "admin_required_api", "cli"]
