@@ -1,24 +1,21 @@
+from apiflask.exceptions import abort
 from flask import jsonify
 from flask.views import MethodView
-from apiflask import input, output, doc
-from apiflask.exceptions import abort
 
+from .decorators import admin_required_api
+from .schemas import TokenInSchema
+from .schemas import TokenOutSchema
 from djask.auth.abstract import AbstractUser
 from djask.blueprints import APIBlueprint
-
-# fmt: off
-from .schemas import (
-    TokenInSchema, TokenOutSchema,
-)
-# fmt: on
-from .decorators import admin_required_api
-from djask.globals import current_app, request, g
 from djask.extensions import db
+from djask.globals import current_app
+from djask.globals import g
+from djask.globals import request
 
-admin_api = APIBlueprint("admin_api", __name__)
+admin_bp = APIBlueprint("admin_api", __name__)
 
 
-@admin_api.route("/user/<int:user_id>")
+@admin_bp.route("/user/<int:user_id>")
 class UserAPI(MethodView):
     decorators = [admin_required_api]
 
@@ -41,11 +38,11 @@ class UserAPI(MethodView):
         return {}, 204
 
 
-@admin_api.route("/user")
+@admin_bp.route("/user")
 class UserCreateAPI(MethodView):
     decorators = [admin_required_api]
 
-    def post(self) -> AbstractUser:
+    def post(self) -> tuple[AbstractUser, int]:
         """Create a user."""
         user = g.User()
         user.update(request.get_json())
@@ -53,10 +50,10 @@ class UserCreateAPI(MethodView):
         return user.to_dict(), 201
 
 
-@admin_api.route("/token")
+@admin_bp.route("/token")
 class TokenAPI(MethodView):
-    @input(TokenInSchema, location="form")
-    @output(TokenOutSchema)
+    @admin_bp.input(TokenInSchema, location="form")
+    @admin_bp.output(TokenOutSchema)
     def post(self, data):
         """Return the access token and expiration."""
         user = (
@@ -78,9 +75,9 @@ class TokenAPI(MethodView):
         return response
 
 
-@admin_api.route("/<model>/<int:model_id>")
+@admin_bp.route("/<model>/<int:model_id>")
 class ModelAPI(MethodView):
-    decorators = [doc(hide=True), admin_required_api]
+    decorators = [admin_bp.doc(hide=True), admin_required_api]
 
     def get(self, model: str, model_id: int):
         """Retrieve an instance of a model."""
@@ -109,9 +106,9 @@ class ModelAPI(MethodView):
         return {}, 204
 
 
-@admin_api.route("/<model>")
+@admin_bp.route("/<model>")
 class ModelCreateAPI(MethodView):
-    decorators = [doc(hide=True), admin_required_api]
+    decorators = [admin_bp.doc(hide=True), admin_required_api]
 
     def post(self, model: str):
         """Create an instance of a model."""
