@@ -1,7 +1,7 @@
 import click
 
-from .views import admin_bp
 from ..globals import current_app
+from .ui.views import admin_bp
 
 
 admin_bp.cli.help = "Create a super user."
@@ -16,10 +16,10 @@ admin_bp.cli.help = "Create a super user."
     confirmation_prompt=True,
     help="The password for the admin",
 )
-def create_superuser(username, password):
+def create_superuser(username: str, password: str):
     User = current_app.config["AUTH_MODEL"]
     user = User(username=username, is_admin=True)
     user.set_password(password)
-    current_app.db.session.add(user)
-    current_app.db.session.commit()
+    current_app.db.session.add(user)  # type: ignore
+    current_app.db.session.commit()  # type: ignore
     click.echo(f"Superuser {username} created!")
