@@ -1,13 +1,16 @@
-import typing as t
-import sqlalchemy as sa
+from __future__ import annotations
 
+from time import time
+from typing import Any
+
+import sqlalchemy as sa
 from apiflask.exceptions import abort
 from authlib.jose import jwt
 from flask_login.mixins import UserMixin
 from sqlalchemy.ext.declarative import AbstractConcreteBase
-from werkzeug.security import generate_password_hash, check_password_hash
+from werkzeug.security import check_password_hash
+from werkzeug.security import generate_password_hash
 
-from ..globals import current_app
 from ..extensions import db
 
 
@@ -47,7 +50,7 @@ class AbstractUser(AbstractConcreteBase, UserMixin):
         """
         return check_password_hash(self.password_hash, password)
 
-    def api_token(self) -> str:
+    def api_token(self, expiration=3600 * 24 * 7) -> str:
         """Generate a new API token for the user.
 
         :param expiration: The expiration time of the token in seconds
@@ -55,15 +58,17 @@ class AbstractUser(AbstractConcreteBase, UserMixin):
         .. versionadded:: 0.3.0
         .. versionchanged:: 0.4.2
         """
+        from ..globals import current_app  # noreorder
+
         header = {"alg": "HS256"}
-        data = {"id": self.id}
+        data = {"id": self.id, "created": time(), "expiration": expiration}
         return jwt.encode(header, data, current_app.config["SECRET_KEY"]).decode()
 
-    def update(self, data: t.Dict[str, t.Any]) -> None:
+    def update(self, data: dict[str, Any]) -> None:
         """Update the user with the given dict.
 
         :param data: The dict containing user data
-        .. versionadded::
+        .. versionadded:: 0.4.2
         """
         for attr, value in data.items():
             if not hasattr(self, attr) and attr != "password":  # pragma: no cover
