@@ -1,17 +1,21 @@
-import typing as t
+from typing import Iterable
 
-from djask.db.models import Model
-from .types import ModelList, ModelType
 from .exceptions import ModelTypeError
+from .types import ModelList
+from .types import ModelType
+from djask.db.models import Model
 
 
 class ModelFunctionalityMixin:
     """
     A mixin that adds some SQL functionalities to the classes which inherit it.
-    Those classes which inherit it are expected to be subclasses of :class:`~flask.Blueprint` or :class:`~flask.Flask`.
+    Those classes which inherit it are expected to be subclasses
+    of :class:`~flask.Blueprint` or :class:`~flask.Flask`.
+
 
-    .. versionadded:: 0.4.1
     .. versionadded:: 0.1.0
+
+    .. versionchanged:: 0.4.0
     """
 
     models: ModelList = []
@@ -29,6 +33,7 @@ class ModelFunctionalityMixin:
     def register_model(self, model: ModelType) -> None:
         """
         Register a model.
+
         :param model: The model to register
         :return: None
         """
@@ -36,9 +41,10 @@ class ModelFunctionalityMixin:
             raise ModelTypeError
         self.models.append(model)
 
-    def register_models(self, models: t.Iterable[ModelType]) -> None:
+    def register_models(self, models: Iterable[ModelType]) -> None:
         """
         Register multiple models at a time.
+
         :param models: The models to register
         :return: None
         """
