@@ -1,5 +1,4 @@
 from djask.db import Model
-from djask.extensions import db
 
 
 def test_new_model(app):
@@ -7,5 +6,4 @@ def test_new_model(app):
     class Test(Model):
         __table_args__ = {"extend_existing": True}
 
-    print(app.spec)
     assert "test" in str(app.spec).lower()
